import React from "react";
import classNames from "classnames";

import Post from "./Post";

const PostList = ({
  className,
  items,
  showAddPostCta,
  currentUser,
  supportThreshold,
  canThumb,
  dimArchived,
  onLike,
  onDislike,
  onHide,
  onBanUser,
  onUnbanUser,
  onAnnounceProcedureProposal,
  onAcceptProcedureProposal,
  onRejectProcedureProposal,
  onRejectProcedureProposalByChairman,
  onEdit,
  onArchive,
  onSeen,
}) => {
  const buildHandler = (responderFn) => (post) => (evt) => {
    evt.preventDefault();
    responderFn(post);
  };

  const onPostLike = buildHandler(onLike);
  const onPostDislike = buildHandler(onDislike);
  const onPostEdit = buildHandler(onEdit);
  const onPostHide = buildHandler(onHide);
  const onPostBanUser = buildHandler(onBanUser);
  const onPostUnbanUser = buildHandler(onUnbanUser);
  const onPostArchive = buildHandler(onArchive);
  const onPostAnnounceProcedureProposal = buildHandler(
    onAnnounceProcedureProposal
  );
  const onPostAcceptProcedureProposal = buildHandler(onAcceptProcedureProposal);
  const onPostRejectProcedureProposal = buildHandler(onRejectProcedureProposal);
  const onPostRejectProcedureProposalByChairman = buildHandler(
    onRejectProcedureProposalByChairman
  );

  const onPostSeen = (post) => () => {
    onSeen(post);
  };

  return (
    <div className={classNames("space-y-px", className)}>
      {items
        .filter((item) => !item.hidden)
        .map((item) => (
          <Post
            key={item.id}
            datetime={item.datetime}
            author={item.author}
            type={item.type}
            state={item.state}
            content={item.contentHtml}
            ranking={item.ranking}
            historyLog={item.historyLog}
            modified={item.modified}
            seen={item.seen}
            archived={item.archived}
            dimIfArchived={dimArchived}
            currentUser={currentUser}
            supportThreshold={supportThreshold}
            canThumb={canThumb}
            onLike={onPostLike(item)}
            onDislike={onPostDislike(item)}
            onHide={onPostHide(item)}
            onBanUser={onPostBanUser(item)}
            onUnbanUser={onPostUnbanUser(item)}
            onAnnounceProcedureProposal={onPostAnnounceProcedureProposal(item)}
            onAcceptProcedureProposal={onPostAcceptProcedureProposal(item)}
            onRejectProcedureProposal={onPostRejectProcedureProposal(item)}
            onRejectProcedureProposalByChairman={onPostRejectProcedureProposalByChairman(
              item
            )}
            onEdit={onPostEdit(item)}
            onArchive={onPostArchive(item)}
            onSeen={onPostSeen(item)}
          />
        ))}
      {showAddPostCta && !items.length && (
        <p className="p-4 lg:p-0 lg:py-3 leading-snug text-sm md:text-base">
          Nikdo zatím žádný odpovídající příspěvek do rozpravy nepřidal. Budeš
          první?
        </p>
      )}
    </div>
  );
};

export default PostList;
